OC.L10N.register(
    "settings",
    {
    "{actor} added you to group {group}" : "{actor} added you to group {group}",
    "You added {user} to group {group}" : "You added {user} to group {group}",
    "{actor} added {user} to group {group}" : "{actor} added {user} to group {group}",
    "An administrator added you to group {group}" : "An administrator added you to group {group}",
    "An administrator added {user} to group {group}" : "An administrator added {user} to group {group}",
    "{actor} removed you from group {group}" : "{actor} removed you from group {group}",
    "You removed {user} from group {group}" : "You removed {user} from group {group}",
    "{actor} removed {user} from group {group}" : "{actor} removed {user} from group {group}",
    "An administrator removed you from group {group}" : "An administrator removed you from group {group}",
    "An administrator removed {user} from group {group}" : "An administrator removed {user} from group {group}",
    "Your <strong>group memberships</strong> were modified" : "Your <strong>group memberships</strong> were modified",
    "{actor} changed your password" : "{actor} changed your password",
    "You changed your password" : "You changed your password",
    "Your password was reset by an administrator" : "Your password was reset by an administrator",
    "Your password was reset" : "Your password was reset",
    "{actor} changed your email address" : "{actor} changed your email address",
    "You changed your email address" : "You changed your email address",
    "Your email address was changed by an administrator" : "Your email address was changed by an administrator",
    "You created an app password for a session named \"{token}\"" : "You created an app password for a session named \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "An administrator created an app password for a session named \"{token}\"",
    "You deleted app password \"{token}\"" : "You deleted app password \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "You renamed app password \"{token}\" to \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "You granted filesystem access to app password \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "You revoked filesystem access from app password \"{token}\"",
    "Security" : "Security",
    "You successfully logged in using two-factor authentication (%1$s)" : "You successfully logged in using two-factor authentication (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "A login attempt using two-factor authentication failed (%1$s)",
    "Remote wipe was started on %1$s" : "Remote wipe was started on %1$s",
    "Remote wipe has finished on %1$s" : "Remote wipe has finished on %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Your <strong>password</strong> or <strong>email</strong> was modified",
    "Settings" : "Settings",
    "Could not remove app." : "Could not remove app.",
    "Could not update app." : "Could not update app.",
    "Wrong password" : "Wrong password",
    "Unable to change personal password" : "Unable to change personal password",
    "Saved" : "Saved",
    "Unable to change password" : "Unable to change password",
    "Unable to change password. Password too long." : "Unable to change password. Password too long.",
    "Authentication error" : "Authentication error",
    "Wrong admin recovery password. Please check the password and try again." : "Wrong admin recovery password. Please check the password and try again.",
    "Administrator documentation" : "Administrator documentation",
    "User documentation" : "User documentation",
    "Nextcloud help overview" : "Nextcloud help overview",
    "Invalid SMTP password." : "Invalid SMTP password.",
    "Email setting test" : "Email setting test",
    "Well done, %s!" : "Well done, %s!",
    "If you received this email, the email configuration seems to be correct." : "If you received this email, the email configuration seems to be correct.",
    "Email could not be sent. Check your mail server log" : "Email could not be sent. Check your mail server log",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "A problem occurred while sending the email. Please revise your settings. (Error: %s)",
    "Invalid mail address" : "Invalid mail address",
    "Settings saved" : "Settings saved",
    "Unable to change full name" : "Unable to change full name",
    "Unable to change email address" : "Unable to change email address",
    "Unable to set invalid phone number" : "Unable to set invalid phone number",
    "Unable to set invalid website" : "Unable to set invalid website",
    "Some account data was invalid" : "Some account data was invalid",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):",
    "%1$s changed your password on %2$s." : "%1$s changed your password on %2$s.",
    "Your password on %s was changed." : "Your password on %s was changed.",
    "Your password on %s was reset by an administrator." : "Your password on %s was reset by an administrator.",
    "Your password on %s was reset." : "Your password on %s was reset.",
    "Password for %1$s changed on %2$s" : "Password for %1$s changed on %2$s",
    "Password changed for %s" : "Password changed for %s",
    "If you did not request this, please contact an administrator." : "If you did not request this, please contact an administrator.",
    "Your email address on %s was changed." : "Your email address on %s was changed.",
    "Your email address on %s was changed by an administrator." : "Your email address on %s was changed by an administrator.",
    "Email address for %1$s changed on %2$s" : "Email address for %1$s changed on %2$s",
    "Email address changed for %s" : "Email address changed for %s",
    "The new email address is %s" : "The new email address is %s",
    "Your %s account was created" : "Your %s account was created",
    "Welcome aboard" : "Welcome aboard",
    "Welcome aboard %s" : "Welcome aboard %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Welcome to your %s account, you can add, protect, and share your data.",
    "Set your password" : "Set your password",
    "Go to %s" : "Go to %s",
    "Install Client" : "Install Client",
    "Apps" : "Apps",
    "Personal" : "Personal",
    "Administration" : "Administration",
    "Users" : "Users",
    "Additional settings" : "Additional settings",
    "Administration privileges" : "Administration privileges",
    "Groupware" : "Groupware",
    "Overview" : "Overview",
    "Basic settings" : "Basic settings",
    "Sharing" : "Sharing",
    "Availability" : "Availability",
    "Calendar" : "Calendar",
    "Personal info" : "Personal info",
    "Mobile & desktop" : "Mobile & desktop",
    "Artificial Intelligence" : "Artificial Intelligence",
    "Email server" : "Email server",
    "Background jobs" : "Background jobs",
    "Unlimited" : "Unlimited",
    "Verifying" : "Verifying",
    "Verifying …" : "Verifying …",
    "Verify" : "Verify",
    "Brute-force Throttle" : "Brute-force Throttle",
    "Your remote address could not be determined." : "Your remote address could not be determined.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly.",
    "Your remote address \"%s\" is not brute-force throttled." : "Your remote address \"%s\" is not brute-force throttled.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root.",
    "Database missing columns" : "Database missing columns",
    "Missing optional column \"%s\" in table \"%s\"." : "Missing optional column \"%s\" in table \"%s\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability.",
    "Database missing indices" : "Database missing indices",
    "Database missing primary keys" : "Database missing primary keys",
    "Missing primary key on table \"%s\"." : "Missing primary key on table \"%s\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running.",
    "Database pending bigint migrations" : "Database pending bigint migrations",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline.",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "This instance is running in debug mode. Only enable this for local development and not in production environments.",
    "Default phone region" : "Default phone region",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file.",
    "Email test" : "Email test",
    "Email test was successfully sent" : "Email test was successfully sent",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "The database is used for transactional file locking. To enhance performance, please configure memcache, if available.",
    "Forwarded for headers" : "Forwarded for headers",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "Your \"trusted_proxies\" setting is not correctly set, it should be an array.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud.",
    "Your IP address was resolved as %s" : "Your IP address was resolved as %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud.",
    "Internet connectivity" : "Internet connectivity",
    "Internet connectivity is disabled in configuration file." : "Internet connectivity is disabled in configuration file.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features.",
    "Old server-side-encryption" : "Old server-side-encryption",
    "Disabled" : "Disabled",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "The old server-side-encryption format is enabled. We recommend disabling this.",
    "Maintenance window start" : "Maintenance window start",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks.",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC",
    "Memcache" : "Memcache",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "No memory cache has been configured. To enhance performance, please configure a memcache, if available.",
    "Configured" : "Configured",
    "PHP default charset" : "PHP default charset",
    "PHP configuration option \"default_charset\" should be UTF-8" : "PHP configuration option \"default_charset\" should be UTF-8",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended.",
    "Freetype" : "Freetype",
    "Supported" : "Supported",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response.",
    "PHP memory limit" : "PHP memory limit",
    "PHP modules" : "PHP modules",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "This instance is missing some required PHP modules. It is required to install them: %s.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation.",
    "PHP version" : "PHP version",
    "You are currently running PHP %s." : "You are currently running PHP %s.",
    "PHP \"output_buffering\" option" : "PHP \"output_buffering\" option",
    "PHP configuration option \"output_buffering\" must be disabled" : "PHP configuration option \"output_buffering\" must be disabled",
    "Random generator" : "Random generator",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "No suitable source for randomness found by PHP which is highly discouraged for security reasons.",
    "Secure" : "Secure",
    "Configuration file access rights" : "Configuration file access rights",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update.",
    "Nextcloud configuration file is writable" : "Nextcloud configuration file is writable",
    "Database version" : "Database version",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\"." : "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\".",
    "Unknown database platform" : "Unknown database platform",
    "Architecture" : "Architecture",
    "64-bit" : "64-bit",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!",
    "Database transaction isolation level" : "Database transaction isolation level",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel.",
    "Was not able to get transaction isolation level: %s" : "Was not able to get transaction isolation level: %s",
    "Profile information" : "Profile information",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled",
    "Nextcloud settings" : "Nextcloud settings",
    "Enable" : "Enable",
    "Machine translation" : "Machine translation",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment.",
    "Image generation" : "Image generation",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "Image generation can be implemented by different apps. Here you can set which app should be used.",
    "None of your currently installed apps provide image generation functionality" : "None of your currently installed apps provide image generation functionality",
    "Text processing" : "Text processing",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task.",
    "Task:" : "Task:",
    "Here you can decide which group can access certain sections of the administration settings." : "Here you can decide which group can access certain sections of the administration settings.",
    "Unable to modify setting" : "Unable to modify setting",
    "None" : "None",
    "Changed disclaimer text" : "Changed disclaimer text",
    "Deleted disclaimer text" : "Deleted disclaimer text",
    "Could not set disclaimer text" : "Could not set disclaimer text",
    "Allow apps to use the Share API" : "Allow apps to use the Share API",
    "Allow resharing" : "Allow resharing",
    "Allow sharing with groups" : "Allow sharing with groups",
    "Restrict users to only share with users in their groups" : "Restrict users to only share with users in their groups",
    "Allow users to share via link and emails" : "Allow users to share via link and emails",
    "Allow public uploads" : "Allow public uploads",
    "Always ask for a password" : "Always ask for a password",
    "Enforce password protection" : "Enforce password protection",
    "Exclude groups from password requirements" : "Exclude groups from password requirements",
    "Exclude groups from creating link shares" : "Exclude groups from creating link shares",
    "Groups excluded from sharing" : "Groups excluded from sharing",
    "Enforce expiration date" : "Enforce expiration date",
    "Default expiration time of new shares in days" : "Default expiration time of new shares in days",
    "Expire shares after x days" : "Expire shares after x days",
    "Set default expiration date for shares to other servers" : "Set default expiration date for shares to other servers",
    "Enforce expiration date for remote shares" : "Enforce expiration date for remote shares",
    "Default expiration time of remote shares in days" : "Default expiration time of remote shares in days",
    "Expire remote shares after x days" : "Expire remote shares after x days",
    "Set default expiration date for shares via link or mail" : "Set default expiration date for shares via link or mail",
    "Default expiration time of shares in days" : "Default expiration time of shares in days",
    "Privacy settings for sharing" : "Privacy settings for sharing",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Show disclaimer text on the public link upload page (only shown when the file list is hidden)",
    "Disclaimer text" : "Disclaimer text",
    "This text will be shown on the public link upload page when the file list is hidden." : "This text will be shown on the public link upload page when the file list is hidden.",
    "Default share permissions" : "Default share permissions",
    "Two-Factor Authentication" : "Two-Factor Authentication",
    "Enforce two-factor authentication" : "Enforce two-factor authentication",
    "Limit to groups" : "Limit to groups",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Enforcement of two-factor authentication can be set for certain groups only.",
    "Two-factor authentication is enforced for all members of the following groups." : "Two-factor authentication is enforced for all members of the following groups.",
    "Enforced groups" : "Enforced groups",
    "Two-factor authentication is not enforced for members of the following groups." : "Two-factor authentication is not enforced for members of the following groups.",
    "Excluded groups" : "Excluded groups",
    "Save changes" : "Save changes",
    "Default" : "Default",
    "Show details for {appName} app" : "Show details for {appName} app",
    "Update to {update}" : "Update to {update}",
    "Remove" : "Remove",
    "Featured" : "Featured",
    "This app is supported via your current Nextcloud subscription." : "This app is supported via your current Nextcloud subscription.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Featured apps are developed by and within the community. They offer central functionality and are ready for production use.",
    "Disable all" : "Disable all",
    "Download and enable all" : "Download and enable all",
    "All apps are up-to-date." : "All apps are up-to-date.",
    "Icon" : "Icon",
    "Name" : "Name",
    "Version" : "Version",
    "Level" : "Level",
    "Actions" : "Actions",
    "Results from other categories" : "Results from other categories",
    "No apps found for your version" : "No apps found for your version",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n app has an update available","%n apps have an update available"],
    "_Update_::_Update all_" : ["Update","Update all"],
    "Failed to create group" : "Failed to create group",
    "Groups" : "Groups",
    "Create group" : "Create group",
    "Group name" : "Group name",
    "Please enter a valid group name" : "Please enter a valid group name",
    "Loading groups…" : "Loading groups…",
    "Loading" : "Loading",
    "Type" : "სახე",
    "Confirm" : "Confirm",
    "Cancel" : "Cancel",
    "Description" : "Description",
    "View in store" : "View in store",
    "Visit website" : "Visit website",
    "Admin documentation" : "Admin documentation",
    "Developer documentation" : "Developer documentation",
    "Details" : "Details",
    "All" : "All",
    "Limit app usage to groups" : "Limit app usage to groups",
    "No results" : "No results",
    "Update to {version}" : "Update to {version}",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "This app cannot be installed because the following dependencies are not fulfilled:",
    "Author" : "Author",
    "Categories" : "Categories",
    "Resources" : "Resources",
    "Documentation" : "Documentation",
    "Interact" : "Interact",
    "Report a bug" : "Report a bug",
    "Request feature" : "Request feature",
    "Ask questions or discuss" : "Ask questions or discuss",
    "Changelog" : "Changelog",
    "Google Chrome for Android" : "Google Chrome for Android",
    "{productName} iOS app" : "{productName} iOS app",
    "{productName} Android app" : "{productName} Android app",
    "{productName} Talk for iOS" : "{productName} Talk for iOS",
    "{productName} Talk for Android" : "{productName} Talk for Android",
    "Sync client" : "Sync client",
    "This session" : "This session",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Device name" : "Device name",
    "Cancel renaming" : "Cancel renaming",
    "Save new name" : "Save new name",
    "Marked for remote wipe" : "Marked for remote wipe",
    "Device settings" : "Device settings",
    "Allow filesystem access" : "Allow filesystem access",
    "Rename" : "Rename",
    "Revoke" : "Revoke",
    "Wipe device" : "Wipe device",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Revoking this token might prevent the wiping of your device if it has not started the wipe yet.",
    "Device" : "Device",
    "Last activity" : "Last activity",
    "Devices & sessions" : "Devices & sessions",
    "Web, desktop and mobile clients currently logged in to your account." : "Web, desktop and mobile clients currently logged in to your account.",
    "Error while creating device token" : "Error while creating device token",
    "App name" : "App name",
    "Create new app password" : "Create new app password",
    "App password copied!" : "App password copied!",
    "Copy app password" : "Copy app password",
    "Login name copied!" : "Login name copied!",
    "Copy login name" : "Copy login name",
    "Could not copy app password. Please copy it manually." : "Could not copy app password. Please copy it manually.",
    "Could not copy login name. Please copy it manually." : "Could not copy login name. Please copy it manually.",
    "New app password" : "New app password",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Use the credentials below to configure your app or device. For security reasons this password will only be shown once.",
    "Login" : "Login",
    "Password" : "პაროლი",
    "Show QR code for mobile apps" : "Show QR code for mobile apps",
    "Use system cron service to call the cron.php file every 5 minutes." : "Use system cron service to call the cron.php file every 5 minutes.",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details.",
    "Unable to update background job mode" : "Unable to update background job mode",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information.",
    "Last job execution ran {time}. Something seems wrong." : "Last job execution ran {time}. Something seems wrong.",
    "Last job ran {relativeTime}." : "Last job ran {relativeTime}.",
    "Background job did not run yet!" : "Background job did not run yet!",
    "AJAX" : "AJAX",
    "Webcron" : "Webcron",
    "Cron (Recommended)" : "Cron (Recommended)",
    "Unable to update profile default setting" : "Unable to update profile default setting",
    "Profile" : "Profile",
    "Unable to update server side encryption config" : "Unable to update server side encryption config",
    "Server-side encryption" : "Server-side encryption",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed.",
    "Enable server-side encryption" : "Enable server-side encryption",
    "No encryption module loaded, please enable an encryption module in the app menu." : "No encryption module loaded, please enable an encryption module in the app menu.",
    "Select default encryption module:" : "Select default encryption module:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}",
    "Enable encryption" : "Enable encryption",
    "Please read carefully before activating server-side encryption:" : "Please read carefully before activating server-side encryption:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases.",
    "Be aware that encryption always increases the file size." : "Be aware that encryption always increases the file size.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data.",
    "This is the final warning: Do you really want to enable encryption?" : "This is the final warning: Do you really want to enable encryption?",
    "Please confirm the group removal" : "Please confirm the group removal",
    "Submit" : "Submit",
    "Rename group" : "Rename group",
    "Current password" : "Current password",
    "New password" : "New password",
    "Change password" : "Change password",
    "Choose your profile picture" : "Choose your profile picture",
    "Please select a valid png or jpg file" : "Please select a valid png or jpg file",
    "Error setting profile picture" : "Error setting profile picture",
    "Error cropping profile picture" : "Error cropping profile picture",
    "Error saving profile picture" : "Error saving profile picture",
    "Error removing profile picture" : "Error removing profile picture",
    "Your profile picture" : "Your profile picture",
    "Upload profile picture" : "Upload profile picture",
    "Choose profile picture from Files" : "Choose profile picture from Files",
    "Remove profile picture" : "Remove profile picture",
    "The file must be a PNG or JPG" : "The file must be a PNG or JPG",
    "Picture provided by original account" : "Picture provided by original account",
    "Set as profile picture" : "Set as profile picture",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Please note that it can take up to 24 hours for your profile picture to be updated everywhere.",
    "You are a member of the following groups:" : "You are a member of the following groups:",
    "Your full name" : "Your full name",
    "Unable to update primary email address" : "Unable to update primary email address",
    "Unable to delete additional email address" : "Unable to delete additional email address",
    "No email address set" : "No email address set",
    "Email options" : "Email options",
    "Remove primary email" : "Remove primary email",
    "Delete email" : "Delete email",
    "This address is not confirmed" : "This address is not confirmed",
    "Unset as primary email" : "Unset as primary email",
    "Set as primary email" : "Set as primary email",
    "Additional email address {index}" : "Additional email address {index}",
    "Unable to delete primary email address" : "Unable to delete primary email address",
    "Unable to add additional email address" : "Unable to add additional email address",
    "Unable to update additional email address" : "Unable to update additional email address",
    "Primary email for password reset and notifications" : "Primary email for password reset and notifications",
    "Your handle" : "Your handle",
    "Your headline" : "Your headline",
    "No language set" : "No language set",
    "Unable to update language" : "Unable to update language",
    "Help translate" : "Help translate",
    "No locale set" : "No locale set",
    "Unable to update locale" : "Unable to update locale",
    "Week starts on {firstDayOfWeek}" : "Week starts on {firstDayOfWeek}",
    "Your city" : "Your city",
    "Your organisation" : "Your organisation",
    "Your phone number" : "Your phone number",
    "Edit your Profile visibility" : "Edit your Profile visibility",
    "Unable to update profile enabled state" : "Unable to update profile enabled state",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected.",
    "Unable to update visibility of {displayId}" : "Unable to update visibility of {displayId}",
    "Your role" : "Your role",
    "Your X (formerly Twitter) handle" : "Your X (formerly Twitter) handle",
    "Your website" : "Your website",
    "Unable to update {property}" : "Unable to update {property}",
    "No {property} set" : "No {property} set",
    "Change scope level of {property}, current scope is {scope}" : "Change scope level of {property}, current scope is {scope}",
    "Unable to update federation scope of the primary {property}" : "Unable to update federation scope of the primary {property}",
    "Unable to update federation scope of additional {property}" : "Unable to update federation scope of additional {property}",
    "Add additional email" : "Add additional email",
    "Add" : "დამატება",
    "Create" : "Create",
    "Change" : "Change",
    "Delete" : "წაშლა",
    "Reshare" : "Reshare",
    "School" : "School",
    "Default language" : "Default language",
    "Common languages" : "Common languages",
    "Other languages" : "Other languages",
    "Password change is disabled because the master key is disabled" : "Password change is disabled because the master key is disabled",
    "Manager" : "Manager",
    "Display name" : "Display name",
    "Either password or email is required" : "Either password or email is required",
    "Password (required)" : "Password (required)",
    "Email (required)" : "Email (required)",
    "Email" : "Email",
    "Quota" : "Quota",
    "Language" : "Language",
    "Set default language" : "Set default language",
    "Total rows summary" : "Total rows summary",
    "Scroll to load more rows" : "Scroll to load more rows",
    "Password or insufficient permissions message" : "Password or insufficient permissions message",
    "Avatar" : "Avatar",
    "Account name" : "ექაუნთის სახელი",
    "Group admin for" : "Group admin for",
    "Storage location" : "Storage location",
    "Last login" : "Last login",
    "Account actions" : "Account actions",
    "{size} used" : "{size} used",
    "Delete account" : "Delete account",
    "Resend welcome email" : "Resend welcome email",
    "Remote wipe of devices" : "Remote wipe of devices",
    "Wipe {userid}'s devices" : "Wipe {userid}'s devices",
    "Wiped {userid}'s devices" : "Wiped {userid}'s devices",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Fully delete {userid}'s account including all their personal files, app data, etc.",
    "Account deletion" : "Account deletion",
    "Delete {userid}'s account" : "Delete {userid}'s account",
    "Display name was successfully changed" : "Display name was successfully changed",
    "Password was successfully changed" : "Password was successfully changed",
    "Email was successfully changed" : "Email was successfully changed",
    "Welcome mail sent!" : "Welcome mail sent!",
    "Change display name" : "Change display name",
    "Set new password" : "Set new password",
    "Set new email address" : "Set new email address",
    "Set the language" : "Set the language",
    "Done" : "დასრულდა",
    "Edit" : "Edit",
    "Visibility" : "Visibility",
    "Show language" : "Show language",
    "Show storage path" : "Show storage path",
    "Show last login" : "Show last login",
    "Sorting" : "Sorting",
    "Send email" : "Send email",
    "Defaults" : "Defaults",
    "Default quota" : "Default quota",
    "Select default quota" : "Select default quota",
    "Server error while trying to complete WebAuthn device registration" : "Server error while trying to complete WebAuthn device registration",
    "Passwordless authentication requires a secure connection." : "Passwordless authentication requires a secure connection.",
    "Add WebAuthn device" : "Add WebAuthn device",
    "Please authorize your WebAuthn device." : "Please authorize your WebAuthn device.",
    "Unnamed device" : "Unnamed device",
    "Passwordless Authentication" : "Passwordless Authentication",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Set up your account for passwordless authentication following the FIDO2 standard.",
    "No devices configured." : "No devices configured.",
    "The following devices are configured for your account:" : "The following devices are configured for your account:",
    "Your browser does not support WebAuthn." : "Your browser does not support WebAuthn.",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "It is important to set up this server to be able to send emails, like for password reset and notifications.",
    "Send mode" : "Send mode",
    "Encryption" : "Encryption",
    "Sendmail mode" : "Sendmail mode",
    "Disable certificate verification (insecure)" : "Disable certificate verification (insecure)",
    "From address" : "From address",
    "Domain" : "Domain",
    "Server address" : "Server address",
    "Host" : "Host",
    "Port" : "Port",
    "Authentication" : "Authentication",
    "Authentication required" : "Authentication required",
    "Saving…" : "Saving…",
    "Security & setup warnings" : "Security & setup warnings",
    "All checks passed." : "All checks passed.",
    "There are some errors regarding your setup." : "There are some errors regarding your setup.",
    "There are some warnings regarding your setup." : "There are some warnings regarding your setup.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "As admin you can fine-tune the sharing behavior. Please see the documentation for more information.",
    "You need to enable the File sharing App." : "You need to enable the File sharing App.",
    "Admins" : "Admins",
    "Location" : "Location",
    "Profile picture" : "Profile picture",
    "About" : "About",
    "Full name" : "Full name",
    "Additional email" : "Additional email",
    "Fediverse (e.g. Mastodon)" : "Fediverse (e.g. Mastodon)",
    "Headline" : "Headline",
    "Organisation" : "Organisation",
    "Phone number" : "Phone number",
    "Role" : "Role",
    "X (formerly Twitter)" : "X (formerly Twitter)",
    "Website" : "Website",
    "Profile visibility" : "Profile visibility",
    "Locale" : "Locale",
    "Private" : "Private",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Only visible to people matched via phone number integration through Talk on mobile",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Not available as this property is required for core functionality including file sharing and calendar invitations",
    "Local" : "Local",
    "Only visible to people on this instance and guests" : "Only visible to people on this instance and guests",
    "Federated" : "Federated",
    "Only synchronize to trusted servers" : "Only synchronize to trusted servers",
    "Published" : "Published",
    "Synchronize to trusted servers and the global and public address book" : "Synchronize to trusted servers and the global and public address book",
    "Your apps" : "Your apps",
    "Active apps" : "Active apps",
    "Disabled apps" : "Disabled apps",
    "Updates" : "Updates",
    "App bundles" : "App bundles",
    "Featured apps" : "Featured apps",
    "Supported apps" : "Supported apps",
    "Show to everyone" : "Show to everyone",
    "Hide" : "Hide",
    "Download and enable" : "Download and enable",
    "Disable" : "Disable",
    "Allow untested app" : "Allow untested app",
    "The app will be downloaded from the App Store" : "The app will be downloaded from the App Store",
    "Unknown" : "Unknown",
    "Never" : "Never",
    "An error occurred during the request. Unable to proceed." : "An error occurred during the request. Unable to proceed.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Error: This app cannot be enabled because it makes the server unstable",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds.",
    "Do you really want to wipe your data from this device?" : "Do you really want to wipe your data from this device?",
    "Confirm wipe" : "Confirm wipe",
    "Could not delete the app token" : "Could not delete the app token",
    "Error while wiping the device with the token" : "Error while wiping the device with the token",
    "Error while updating device token name" : "Error while updating device token name",
    "Error while updating device token scope" : "Error while updating device token scope",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "There were too many requests from your network. Retry later or contact your administrator if this is an error.",
    "Error" : "Error",
    "Account documentation" : "Account documentation",
    "Administration documentation" : "Administration documentation",
    "Forum" : "Forum",
    "General documentation" : "General documentation",
    "Legal notice" : "Legal notice",
    "Privacy policy" : "Privacy policy",
    "Reasons to use Nextcloud in your organization" : "Reasons to use Nextcloud in your organization",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Like our Facebook page",
    "Follow us on Mastodon" : "Follow us on Mastodon",
    "Check out our blog" : "Check out our blog",
    "Subscribe to our newsletter" : "Subscribe to our newsletter",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "This community release of Nextcloud is unsupported and instant notifications are unavailable.",
    "Open documentation" : "Open documentation",
    "Use a second factor besides your password to increase security for your account." : "Use a second factor besides your password to increase security for your account.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication.",
    "Very weak password" : "Very weak password",
    "Weak password" : "Weak password",
    "So-so password" : "So-so password",
    "Good password" : "Good password",
    "Strong password" : "Strong password",
    "Group list is empty" : "Group list is empty",
    "Unable to retrieve the group list" : "Unable to retrieve the group list",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "This app has no minimum Nextcloud version assigned. This will be an error in the future.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "This app has no maximum Nextcloud version assigned. This will be an error in the future.",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet.",
    "Adding your device …" : "Adding your device …",
    "Sending…" : "Sending…",
    "Email sent" : "Email sent",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected.",
    "None/STARTTLS" : "None/STARTTLS",
    "SSL" : "SSL",
    "Credentials" : "Credentials",
    "SMTP Password" : "SMTP Password",
    "Save" : "Save",
    "Test and verify email settings" : "Test and verify email settings",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information.",
    "Checking for system and security issues." : "Checking for system and security issues.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>."
},
"nplurals=2; plural=(n!=1);");
